@@ -17,13 +17,32 @@
     Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  */
 
+#ifdef HAVE_CONFIG_H
+#include "config.h"
+#endif
+
 /*   if.h - include file for if routines
  * Include this in all files which need to think about if statements
  */
 
 typedef struct if_stack {
-  int stat, active;       /* 0 for false, 1 for true */
-  struct if_stack *prev;  /* The if statment, one level up */
+  int stat;               /* 0 for false, 1 for true */
+  int active;             /* if the code inside the if statement shouldn't
+                           * be executed because of a surounding if statement,
+                           * set this to 0.  Set to 1 otherwise */
+
+#ifdef NEW_SCANNER
+  /* extra code to extend if stack to handle while and print_loops */
+  /* for while and print loops, loop_start gives the file position for
+   * the initial loop command, and stat is set to 1.  When the loop should
+   * be broken from, stat is set to 0.
+   */
+  enum { LOOP_IF, LOOP_WHILE, LOOP_PRINT } loop_type;
+  long loop_start;
+  int looping;     /* set by 'done' to indicate that we are looping around */
+  void *data;      /* for a print_loop, this holds the query handle */
+#endif
+  struct if_stack *prev;  /* The if statement, one level up */
 } IFSTACK;
 
 extern IFSTACK *curIf;
